@@ -12,7 +12,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # experiments.py
-# Copyright (C) 2014-2016 Fracpete (pythonwekawrapper at gmail dot com)
+# Copyright (C) 2014-2022 Fracpete (pythonwekawrapper at gmail dot com)
 
 import logging
 import javabridge
@@ -53,7 +53,8 @@ class SimpleExperiment(OptionHandler):
     http://weka.wikispaces.com/Using+the+Experiment+API
     """
 
-    def __init__(self, datasets, classifiers, jobject=None, classification=True, runs=10, result=None):
+    def __init__(self, datasets, classifiers, jobject=None, classification=True, runs=10, result=None,
+                 class_for_ir_statistics=0, attribute_id=-1, pred_target_column=False):
         """
         Initializes the experiment.
 
@@ -69,6 +70,12 @@ class SimpleExperiment(OptionHandler):
         :type runs: int
         :param result: the filename of the file to store the results in
         :type result: str
+        :param class_for_ir_statistics: the class label index to use IR statistics (classification only)
+        :type class_for_ir_statistics: int
+        :param attribute_id: the 0-based index of the attribute identifying instances (classification only)
+        :type attribute_id: int
+        :param pred_target_column: whether to store the predicted and target columns as well (classification only)
+        :type pred_target_column: bool
         """
 
         if not jobject is None:
@@ -81,6 +88,9 @@ class SimpleExperiment(OptionHandler):
         self.datasets = datasets[:]
         self.classifiers = classifiers[:]
         self.result = result
+        self.class_for_ir_statistics = class_for_ir_statistics
+        self.attribute_id = attribute_id
+        self.pred_target_column = pred_target_column
         super(SimpleExperiment, self).__init__(jobject=jobject)
 
     def configure_splitevaluator(self):
@@ -92,8 +102,12 @@ class SimpleExperiment(OptionHandler):
         """
         if self.classification:
             speval = javabridge.make_instance("weka/experiment/ClassifierSplitEvaluator", "()V")
+            javabridge.call(speval, "setClassForIRStatistics", "(I)V", self.class_for_ir_statistics)
+            javabridge.call(speval, "setAttributeID", "(I)V", self.attribute_id)
+            javabridge.call(speval, "setPredTargetColumn", "(Z)V", self.pred_target_column)
         else:
             speval = javabridge.make_instance("weka/experiment/RegressionSplitEvaluator", "()V")
+
         classifier = javabridge.call(speval, "getClassifier", "()Lweka/classifiers/Classifier;")
         return speval, classifier
 
@@ -221,7 +235,8 @@ class SimpleCrossValidationExperiment(SimpleExperiment):
     Performs a simple cross-validation experiment. Can output the results either in ARFF or CSV.
     """
 
-    def __init__(self, datasets, classifiers, classification=True, runs=10, folds=10, result=None):
+    def __init__(self, datasets, classifiers, classification=True, runs=10, folds=10, result=None,
+                 class_for_ir_statistics=0, attribute_id=-1, pred_target_column=False):
         """
         Initializes the experiment.
 
@@ -237,6 +252,12 @@ class SimpleCrossValidationExperiment(SimpleExperiment):
         :type folds: int
         :param result: the filename of the file to store the results in
         :type result: str
+        :param class_for_ir_statistics: the class label index to use IR statistics (classification only)
+        :type class_for_ir_statistics: int
+        :param attribute_id: the 0-based index of the attribute identifying instances (classification only)
+        :type attribute_id: int
+        :param pred_target_column: whether to store the predicted and target columns as well (classification only)
+        :type pred_target_column: bool
         """
 
         if runs < 1:
@@ -252,7 +273,9 @@ class SimpleCrossValidationExperiment(SimpleExperiment):
 
         super(SimpleCrossValidationExperiment, self).__init__(
             classification=classification, runs=runs, datasets=datasets,
-            classifiers=classifiers, result=result)
+            classifiers=classifiers, result=result,
+            class_for_ir_statistics=class_for_ir_statistics, attribute_id=attribute_id,
+            pred_target_column=pred_target_column)
 
         self.folds = folds
 
@@ -293,7 +316,7 @@ class SimpleRandomSplitExperiment(SimpleExperiment):
     """
 
     def __init__(self, datasets, classifiers, classification=True, runs=10, percentage=66.6, preserve_order=False,
-                 result=None):
+                 result=None, class_for_ir_statistics=0, attribute_id=-1, pred_target_column=False):
         """
         Initializes the experiment.
 
@@ -311,6 +334,12 @@ class SimpleRandomSplitExperiment(SimpleExperiment):
         :type classifiers: list
         :param result: the filename of the file to store the results in
         :type result: str
+        :param class_for_ir_statistics: the class label index to use IR statistics (classification only)
+        :type class_for_ir_statistics: int
+        :param attribute_id: the 0-based index of the attribute identifying instances (classification only)
+        :type attribute_id: int
+        :param pred_target_column: whether to store the predicted and target columns as well (classification only)
+        :type pred_target_column: bool
         """
 
         if runs < 1:
@@ -328,7 +357,9 @@ class SimpleRandomSplitExperiment(SimpleExperiment):
 
         super(SimpleRandomSplitExperiment, self).__init__(
             classification=classification, runs=runs, datasets=datasets,
-            classifiers=classifiers, result=result)
+            classifiers=classifiers, result=result,
+            class_for_ir_statistics=class_for_ir_statistics, attribute_id=attribute_id,
+            pred_target_column=pred_target_column)
 
         self.percentage = percentage
         self.preserve_order = preserve_order
@@ -622,7 +653,7 @@ class Tester(OptionHandler):
     For generating statistical results from an experiment.
     """
 
-    def __init__(self, classname="weka.experiment.PairedCorrectedTTester", jobject=None, options=None):
+    def __init__(self, classname="weka.experiment.PairedCorrectedTTester", jobject=None, options=None, swap_rows_and_cols=False):
         """
         Initializes the specified tester using either the classname or the supplied JB_Object.
 
@@ -632,17 +663,41 @@ class Tester(OptionHandler):
         :type jobject: JB_Object
         :param options: the list of commandline options to set
         :type options: list
+        :param swap_rows_and_cols: whether to swap rows/columns, to compare datasets rather than classifiers
+        :type swap_rows_and_cols: bool
         """
         if jobject is None:
             jobject = Tester.new_instance(classname)
         self.enforce_type(jobject, "weka.experiment.Tester")
         self.columns_determined = False
-        self._dataset_columns = ["Key_Dataset"]
         self._run_column = "Key_Run"
         self._fold_column = "Key_Fold"
+        self._swap_rows_and_cols = swap_rows_and_cols
+        self._dataset_columns = ["Key_Dataset"]
         self._result_columns = ["Key_Scheme", "Key_Scheme_options", "Key_Scheme_version_ID"]
         super(Tester, self).__init__(jobject=jobject, options=options)
 
+    @property
+    def swap_rows_and_cols(self):
+        """
+        Returns whether to swap rows/cols.
+
+        :return: whether to swap
+        :rtype: bool
+        """
+        return self._swap_rows_and_cols
+
+    @swap_rows_and_cols.setter
+    def swap_rows_and_cols(self, swap):
+        """
+        Sets whether to swap rows/cols.
+
+        :param swap: whether to swap
+        :type swap: bool
+        """
+        self.columns_determined = False
+        self._swap_rows_and_cols = swap
+
     @property
     def resultmatrix(self):
         """
@@ -780,11 +835,18 @@ class Tester(OptionHandler):
             print("No instances set, cannot determine columns!")
             return
 
+        if self.swap_rows_and_cols:
+            dataset_columns = self.result_columns
+            result_columns = self.dataset_columns
+        else:
+            dataset_columns = self.dataset_columns
+            result_columns = self.result_columns
+
         # dataset
-        if self.dataset_columns is None:
+        if dataset_columns is None:
             raise Exception("No dataset columns set!")
         cols = ""
-        for name in self.dataset_columns:
+        for name in dataset_columns:
             att = data.attribute_by_name(name)
             if att is None:
                 raise Exception("Dataset column not found: " + name)
@@ -814,10 +876,10 @@ class Tester(OptionHandler):
                 self.jobject, "setFoldColumn", "(I)V", index)
 
         # result
-        if self._result_columns is None:
-            raise Exception("No reset columns set!")
+        if result_columns is None:
+            raise Exception("No result columns set!")
         cols = ""
-        for name in self._result_columns:
+        for name in result_columns:
             att = data.attribute_by_name(name)
             if att is None:
                 raise Exception("Result column not found: " + name)
